@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.9 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.10 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.9 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.10 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowUpd extends SyL_AdmFlow
@@ -193,7 +193,7 @@ class SyL_AdmFlowUpd extends SyL_AdmFlow
      */
     function validateAdm(&$adm)
     {
-        return $adm->validateAdm();
+        return $adm->validate();
     }
 
     /**
