@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.10 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.11 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.10 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.11 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperationLst extends SyL_AdmOperation
@@ -85,11 +85,11 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
                 if ($alias == $data_source['alias']) {
                     if ($name != $data_source['value']) {
                         $tmp_option_column = $option_tmp_column . $option_tmp_index++;
-                        $table->addColumn($data_source['value'], $tmp_option_column);
+                        $table->set($data_source['value'], $tmp_option_column);
                         $data_sources[$name]['value'] = $tmp_option_column;
                     }
                     $tmp_option_column = $option_tmp_column . $option_tmp_index++;
-                    $table->addColumn($data_source['name'], $tmp_option_column);
+                    $table->set($data_source['name'], $tmp_option_column);
                     $data_sources[$name]['name'] = $tmp_option_column;
                 }
             }
