@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationUpd.php,v 1.7 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationUpd.php,v 1.8 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationUpd.php,v 1.7 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationUpd.php,v 1.8 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperationUpd extends SyL_AdmOperation
@@ -64,8 +64,8 @@ class SyL_AdmOperationUpd extends SyL_AdmOperation
                 $table = $this->tables[$data_source['alias']];
             }
             $table->initDataColumns();
-            $table->addColumn($data_source['name']);
-            $table->addColumn($data_source['value']);
+            $table->set($data_source['name']);
+            $table->set($data_source['value']);
             $table->addSort($data_source['name']);
             $table->addSort($data_source['value']);
 
@@ -226,10 +226,10 @@ class SyL_AdmOperationUpd extends SyL_AdmOperation
                         if (($value !== '') && ($value !== null)) {
                             // ǥեͤܤϤƤͥ
                             unset($defaults[$name]);
-                            $table->addColumn($name, $value);
+                            $table->set($name, $value);
                         }
                     } else {
-                        $table->addColumn($name, $value);
+                        $table->set($name, $value);
                     }
                 }
                 // ǥեͤХå
@@ -238,16 +238,16 @@ class SyL_AdmOperationUpd extends SyL_AdmOperation
                         if (count($value) > 1) {
                             switch ($value[0]) {
                             case 'eval':
-                                $table->addColumn($name, eval("return {$value[1]};"));
+                                $table->set($name, eval("return {$value[1]};"));
                                 break;
                             case 'function':
                                 array_shift($value);
-                                $table->addColumn($name, $value);
+                                $table->set($name, $value);
                                 break;
                             }
                         }
                     } else {
-                        $table->addColumn($name, $value);
+                        $table->set($name, $value);
                     }
                 }
                 // 索֥Ⱥ
