@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.11 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.12 2008/12/01 17:45:53 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/lib/DB/Dao/SyL_DBDaoTable.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.11 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.12 2008/12/01 17:45:53 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperation
@@ -148,7 +148,7 @@ class SyL_AdmOperation
         // ɽ
         foreach ($this->form->getListColumns($alias) as $column) {
             // ơ֥륪֥Ȥ˼ɲ
-            $table->addColumn($column);
+            $table->set($column);
             // ơ֥Хǡɲ
             $column_def = $table->getColumn($column);
             if (isset($column_def['validate'])) {
