@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.31 2008/11/09 10:05:35 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.32 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Action.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.31 2008/11/09 10:05:35 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.32 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -125,7 +125,7 @@ class SyL_ConfigActions extends SyL_Config
     function parseXml($enable_cache=true)
     {
         // ١饹
-        SyL_Loader::lib(SYL_ACTION_BASE_CLASS);
+        SyL_Loader::userLib(SYL_ACTION_BASE_CLASS);
 
         if (SYL_CACHE && $enable_cache) {
             // åѤ
