@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.13 2008/11/09 10:05:35 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.14 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.13 2008/11/09 10:05:35 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.14 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigLayouts extends SyL_Config
@@ -59,7 +59,16 @@ class SyL_ConfigLayouts extends SyL_Config
      */
     function setProjectConfigFiles()
     {
-        $this->file_names[] = SYL_APP_CONFIG_DIR . "/{$this->config_file_name}";
+        // ץꥱ쥤ե
+        $config = SYL_APP_CONFIG_DIR . "/{$this->config_file_name}";
+        if (is_file($config)) {
+            $this->file_names[] = $config;
+        }
+        // ץȥ쥤ե
+        $config = SYL_PROJECT_CONFIG_DIR . "/{$this->config_file_name}";
+        if (is_file($config)) {
+            $this->file_names[] = $config;
+        }
     }
 
     /**
