@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigRouters.php,v 1.5 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigRouters.php,v 1.6 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigRouters.php,v 1.5 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigRouters.php,v 1.6 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigRouters extends SyL_Config
@@ -76,7 +76,7 @@ class SyL_ConfigRouters extends SyL_Config
         if (count($this->file_names) > 0) {
             if (SYL_CACHE && $enable_cache) {
                 // åѤ
-                $key = SYL_APP_DIR;
+                $key = SYL_APP_DIR . $this->router->getActionFile();
                 $cache =& $this->getCache($key);
                 if ($cache) {
                     // å夬Ǥʤäʥå奪֥Ȥ
@@ -101,31 +101,44 @@ class SyL_ConfigRouters extends SyL_Config
      */
     function getElement($current_path, $attribute, $text)
     {
+        static $load = false;
+
+        // 1ɺѤߤξʹߥå
+        if ($load) return;
+
         // XMLϷ̤
         switch ($current_path) {
         case '/syl-routers/router':
-            $enable_action   = true;
-            $enable_template = true;
-            if (isset($attribute['enableAction'])) {
-                $enable_action = ($attribute['enableAction'] == 'true');
-            }
-            if (isset($attribute['enableTemplate'])) {
-                $enable_template = ($attribute['enableTemplate'] == 'true');
+            if (isset($attribute['enable']) && ($attribute['enable'] === 'false')) {
+                return;
             }
 
-            if (!$enable_action && !$enable_template) {
-                break;
+            // ̾ǧ
+            $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
+            // եѥ롼֥
+            if (preg_match('/^' . $reg . '$/', '/'.$this->router->getActionFile())) {
+                $load = true;
+                $enable_action   = true;
+                $enable_template = true;
+                if (isset($attribute['enableAction'])) {
+                    $enable_action = ($attribute['enableAction'] == 'true');
+                }
+                if (isset($attribute['enableTemplate'])) {
+                    $enable_template = ($attribute['enableTemplate'] == 'true');
+                }
+
+                if (!$enable_action && !$enable_template) {
+                    break;
+                }
+
+                $this->config = array();
+                $this->config['forwardAction']   = isset($attribute['forwardAction'])   ? $attribute['forwardAction']   : '';
+                $this->config['forwardTemplate'] = isset($attribute['forwardTemplate']) ? $attribute['forwardTemplate'] : '';
+                $this->config['viewType']        = isset($attribute['viewType'])      ? $attribute['viewType']      : '';
+                $this->config['layoutName']      = isset($attribute['layoutName'])    ? $attribute['layoutName']    : '';
+                $this->config['enableAction']    = $enable_action;
+                $this->config['enableTemplate']  = $enable_template;
             }
-
-            $request_action = $attribute['requestAction'];
-
-            $this->config[$request_action] = array();
-            $this->config[$request_action]['forwardAction']   = isset($attribute['forwardAction'])   ? $attribute['forwardAction']   : '';
-            $this->config[$request_action]['forwardTemplate'] = isset($attribute['forwardTemplate']) ? $attribute['forwardTemplate'] : '';
-            $this->config[$request_action]['viewType']        = isset($attribute['viewType'])      ? $attribute['viewType']      : '';
-            $this->config[$request_action]['layoutName']      = isset($attribute['layoutName'])    ? $attribute['layoutName']    : '';
-            $this->config[$request_action]['enableAction']    = $enable_action;
-            $this->config[$request_action]['enableTemplate']  = $enable_template;
             break;
         }
     }
