@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.23 2008/11/09 10:05:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.24 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.23 2008/11/09 10:05:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.24 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterParameter extends SyL_Router
@@ -47,10 +47,17 @@ class SyL_RouterParameter extends SyL_Router
     /**
      * ζڤʸ
      *
-     * @access private
+     * @access protected
      * @var string
      */
     var $action_delimiter = '.';
+    /**
+     * ᥽åɤζڤʸ
+     *
+     * @access protected
+     * @var string
+     */
+    var $method_delimiter = ':';
 
     /**
      * ܾ󥪥֥ȤΥץѥƥ
@@ -60,34 +67,39 @@ class SyL_RouterParameter extends SyL_Router
      */
     function createActionInfo(&$data)
     {
-        $pathinfo = array();
-        // ѥ᡼ SYL_ACTION_KEY Ǽѥ᡼
-        $action   = $data->get(SYL_ACTION_KEY);
-        if ($action === null) {
-            $action = $data->geta(SYL_ACTION_KEY, 0);
-        }
-        $pathinfo = explode($this->action_delimiter, $action);
+        $this->setRouterInfo($data->geta(SYL_ACTION_KEY, 0));
+    }
 
-        switch (count($pathinfo)) {
-        case 0:
+    /**
+     * ܾ󥪥֥ȤΥץѥƥ
+     *
+     * @access protected
+     * @param string ̾
+     */
+    function setRouterInfo($action)
+    {
+        if ($action === null) {
             $this->action_method = '';
-            $this->setActionFile(ucfirst($this->action_file_default));
-            break;
-        case 1:
-            $this->action_method = array_pop($pathinfo);
-            $this->setActionFile(ucfirst($this->action_file_default));
-            break;
-        default:
-            $this->action_method = array_pop($pathinfo);
-            $this->setActionFile(implode('/', array_map('ucfirst', $pathinfo)) . $this->exe_ext);
-            array_pop($pathinfo); // ե̾
-            break;
+            $this->action_file = $this->action_file_default;
+        } else {
+            $actions_path = explode($this->action_delimiter, $action);
+            $method   = explode($this->method_delimiter, $actions_path[count($actions_path)-1], 2);
+
+            $this->action_method = (count($method) == 2) ? ucfirst($method[1]) : $this->action_method;
+            array_pop($actions_path);
+            $action_dir = implode('/', array_map('ucfirst', $actions_path));
+            if ($action_dir) {
+                $this->action_file = $action_dir . '/' . ucfirst($method[0]) . $this->exe_ext;
+            } else {
+                $this->action_file = ucfirst($method[0]) . $this->exe_ext;
+            }
         }
 
         // ƥץ졼ȥե
         $this->setTemplateFile(substr($this->action_file, 0, intval('-' . strlen($this->exe_ext))) . SYL_ROUTER_URL_EXT);
+        // ꥸʥ륢ե
+        $this->action_file_org = $this->action_file;
     }
-
 }
 
 ?>
