@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.23 2008/11/09 10:05:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.24 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.23 2008/11/09 10:05:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.24 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo extends SyL_Router
@@ -65,56 +65,54 @@ class SyL_RouterPathinfo extends SyL_Router
 
         if ($pathinfo == '') {
             $this->action_method = '';
-            $this->setActionFile(ucfirst($this->action_file_default));
+            $this->action_file = $this->action_file_default;
         } else if (substr($pathinfo, -1) == '/') {
             $this->action_method = '';
-            $this->setActionFile(implode('/', array_map('ucfirst', explode('/', $pathinfo))) . $this->action_file_default);
+            $this->action_file = implode('/', array_map('ucfirst', explode('/', $pathinfo))) . $this->action_file_default;
         } else {
             // ĥȽ
-            if ($this->url_ext && !preg_match('/^(.+)(' . preg_quote($this->url_ext) . ')$/', $pathinfo)) {
+            if (SYL_ROUTER_URL_EXT && !preg_match('/^(.+)(' . preg_quote(SYL_ROUTER_URL_EXT) . ')$/', $pathinfo)) {
                 SyL_Response::forwardFileNotFound();
             }
             $pathinfo_file  = basename($pathinfo);
             $pathinfo_dir   = dirname($pathinfo);
             $pathinfo_files = explode($this->action_delimiter, $pathinfo_file, 2);
 
-            // windowsб
-            if ($pathinfo_dir == '\\') {
+            switch ($pathinfo_dir) {
+            case '':
+            case '\\':
+            case '/':
                 $pathinfo_dir = '';
+                break;
+            default:
+                $pathinfo_dir = substr($pathinfo_dir, 1);
+                $pathinfo_dir = implode('/', array_map('ucfirst', explode('/', $pathinfo_dir))) . '/';
+                break;
             }
-
-            if ($pathinfo_dir != '/') {
-                $pathinfo_dir .= '/';
-            }
-
-            // ƬʸѴ
-            $pathinfo_dir = implode('/', array_map('ucfirst', explode('/', $pathinfo_dir)));
-            $action_file = '';
             if (count($pathinfo_files) == 2) {
-                if (($this->action_delimiter == '.') && ($this->url_ext == ('.' . $pathinfo_files[1]))) {
+                if (($this->action_delimiter == '.') && (SYL_ROUTER_URL_EXT == ('.' . $pathinfo_files[1]))) {
                     // ᥽åɤʤ
                     $this->action_method = '';
-                    $action_file = $pathinfo_dir . ucfirst($pathinfo_files[0]) . $this->exe_ext;
+                    $this->action_file = $pathinfo_dir . ucfirst($pathinfo_files[0]) . $this->exe_ext;
                 } else {
                     $this->action_method = ucfirst($pathinfo_files[0]);
-                    if (preg_match('/^(.+)(' . preg_quote($this->url_ext) . '|' . preg_quote($this->exe_ext) . ')$/', $pathinfo_files[1], $matches)) {
+                    if (preg_match('/^(.+)(' . preg_quote(SYL_ROUTER_URL_EXT) . '|' . preg_quote($this->exe_ext) . ')$/', $pathinfo_files[1], $matches)) {
                         // ᥽åɤ
-                        $action_file = $pathinfo_dir . ucfirst($matches[1]) . $this->exe_ext;
+                        $this->action_file = $pathinfo_dir . ucfirst($matches[1]) . $this->exe_ext;
                     } else {
                         // ᥽åɤ
-                        $action_file = $pathinfo_dir . ucfirst($pathinfo_files[1]) . $this->exe_ext;
+                        $this->action_file = $pathinfo_dir . ucfirst($pathinfo_files[1]) . $this->exe_ext;
                     }
                 }
             } else {
                 // ᥽åɤʤ
                 $this->action_method = '';
-                if (preg_match('/^(.+)(' . preg_quote($this->url_ext) . '|' . preg_quote($this->exe_ext) . ')$/', $pathinfo_files[1], $matches)) {
-                    $action_file = $pathinfo_dir . ucfirst($matches[1]) . $this->exe_ext;
+                if (preg_match('/^(.+)(' . preg_quote(SYL_ROUTER_URL_EXT) . '|' . preg_quote($this->exe_ext) . ')$/', $pathinfo_files[1], $matches)) {
+                    $this->action_file = $pathinfo_dir . ucfirst($matches[1]) . $this->exe_ext;
                 } else {
-                    $action_file = $pathinfo_dir . ucfirst($pathinfo_files[1]) . $this->exe_ext;
+                    $this->action_file = $pathinfo_dir . ucfirst($pathinfo_files[1]) . $this->exe_ext;
                 }
             }
-            $this->setActionFile($action_file);
         }
 
         // ƥץ졼ȥե
@@ -140,6 +138,9 @@ class SyL_RouterPathinfo extends SyL_Router
             $this->action_method = ucfirst($action_method);
         }
 
+        // ꥸʥ륢ե
+        $this->action_file_org = $this->action_file;
+
 /*
 echo "action_method: " . $this->action_method . "<br>";
 echo "action_file: " . $this->action_file . "<br>";
