@@ -27,11 +27,16 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.11 2008/11/09 10:05:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.12 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
+/**
+ * ѥ᡼ե졼ͤ륯饹
+ */
+require_once 'SyL_RouterParameter.php';
+
 /**
  * XML᥽åɤե졼ͤ륯饹
  *
@@ -39,19 +44,11 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.11 2008/11/09 10:05:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterXmlrpc.php,v 1.12 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
-class SyL_RouterXmlrpc extends SyL_Router
+class SyL_RouterXmlrpc extends SyL_RouterParameter
 {
-    /**
-     * ζڤʸ
-     *
-     * @access private
-     * @var string
-     */
-    var $action_delimiter = '.';
-
     /**
      * ܾ󥪥֥ȤΥץѥƥ
      *
@@ -60,25 +57,9 @@ class SyL_RouterXmlrpc extends SyL_Router
      */
     function createActionInfo(&$data)
     {
-         // SyL_DataXmlrpc饹ǥåȤ
-        $pathinfo = explode($this->action_delimiter, $data->get(0));
-
-        switch (count($pathinfo)) {
-        case 0:
-            $this->action_method = '';
-            $this->setActionFile(ucfirst($this->action_file_default));
-            break;
-        case 1:
-            $this->action_method = array_pop($pathinfo);
-            $this->setActionFile(ucfirst($this->action_file_default));
-            break;
-        default:
-            $this->action_method = array_pop($pathinfo);
-            $this->setActionFile('/' . implode('/', array_map('ucfirst', $pathinfo)) . $this->exe_ext);
-            break;
-        }
+        // SyL_DataXmlrpc饹ǥåȤ
+        $this->setRouterInfo($data->get(0));
     }
-
 }
 
 ?>
