@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.23 2008/11/09 10:05:35 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.24 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.23 2008/11/09 10:05:35 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.24 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Context
@@ -257,7 +257,7 @@ class SyL_Context
      */
     function addLogDBError($message)
     {
-        SyL_Loggers::error($message);
+        SyL_Loggers::warn($message);
     }
 
 
