@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.11 2008/11/09 10:05:35 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.12 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.11 2008/11/09 10:05:35 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.12 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Data extends SyL_UtilProperty
@@ -145,7 +145,7 @@ class SyL_Data extends SyL_UtilProperty
      * @param string ͭɽ
      * @return string ץѥƥ
      */
-    function get($name, $default=null, $reg=null)
+    function get($name, $default=null, $valid=null)
     {
         $value = parent::get($name);
         if (($value === null) && isset($this->input_parameters[$name])) {
@@ -158,9 +158,9 @@ class SyL_Data extends SyL_UtilProperty
         if ($value === null) {
             return $default;
         } else {
-            if ($reg !== null) {
-                $reg = "/{$reg}/";
-                return preg_match($reg, $value) ? $value : $default;
+            if ($valid !== null) {
+                $valid = "/{$valid}/";
+                return preg_match($valid, $value) ? $value : $default;
             } else {
                 return $value;
             }
@@ -209,9 +209,9 @@ class SyL_Data extends SyL_UtilProperty
         if ($value === null) {
             return $default;
         } else {
-            if ($reg !== null) {
-                $reg = "/{$reg}/";
-                return preg_match($reg, $value) ? $value : $default;
+            if ($valid !== null) {
+                $valid = "/{$valid}/";
+                return preg_match($valid, $value) ? $value : $default;
             } else {
                 return $value;
             }
