@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.23 2008/11/09 10:05:35 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.24 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.23 2008/11/09 10:05:35 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.24 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
@@ -52,13 +52,6 @@ class SyL_Router
      * @var string
      */
     var $action_file_default = 'Index.php';
-    /**
-     * URLγĥ
-     *
-     * @access protected
-     * @var string
-     */
-    var $url_ext = SYL_ROUTER_URL_EXT;
     /**
      * ¹ԥեγĥ
      *
@@ -87,6 +80,13 @@ class SyL_Router
      * @var string
      */
     var $action_file = '';
+    /**
+     * եʥꥸʥ
+     *
+     * @access protected
+     * @var string
+     */
+    var $action_file_org = '';
     /**
      * ƥץ졼ȥե
      *
@@ -188,20 +188,6 @@ class SyL_Router
         return $this->template_dir;
     }
 
-    /**
-     * ե򥻥å
-     *
-     * @access public
-     * @param string ե
-     */
-    function setActionFile($action_file)
-    {
-        if ($action_file[0] == '/') {
-            $action_file = substr($action_file, 1);
-        }
-        $this->action_file = $action_file;
-    }
-
     /**
      * ե
      *
@@ -237,8 +223,8 @@ class SyL_Router
     function getTemplateFile($trigger_error_404=true)
     {
         // ƥץ졼ȥե¸ߥå
-        if ($trigger_error_404 && !is_file($this->getTemplateDir() . $this->template_file)) {
-            SyL_Loggers::warn("Template file not found dir: {$template_dir} file: {$template_file}");
+        if ($trigger_error_404 && !is_file($this->template_dir . $this->template_file)) {
+            SyL_Loggers::warn("Template file not found dir: {$this->template_dir} file: {$this->template_file}");
             SyL_Response::forwardFileNotFound();
         }
         return $this->template_file;
@@ -252,7 +238,8 @@ class SyL_Router
      */
     function getClassName()
     {
-        return $this->createActionClass();
+        $classname = str_replace('/', '_', $this->action_file);
+        return preg_replace('/(' . preg_quote($this->exe_ext) . ')$/', '', $classname);
     }
 
     /**
@@ -300,15 +287,25 @@ class SyL_Router
     }
 
     /**
-     * 󥯥饹̾
+     * ѥ̤˼
      *
-     * @access protected
-     * @return string 󥯥饹̾
+     * @access public
+     * @return array Ƴ̾
      */
-    function createActionClass()
+    function getUrlNames()
     {
-        $classname = str_replace('/', '_', $this->action_file);
-        return preg_replace('/(' . preg_quote($this->exe_ext) . ')$/', '', $classname);
+        $url_names = array();
+        foreach (explode('/', dirname($this->action_file_org)) as $url_name) {
+            switch ($url_name) {
+            case '':
+            case '.':
+            case '\\':
+                break;
+            default:
+                $url_names[] = $url_name;
+            }
+        }
+        return $url_names;
     }
 
     /**
@@ -324,7 +321,11 @@ class SyL_Router
         $router = $config->getConfig();
         if ($router) {
             if ($router['enableAction'] && $router['forwardAction']) {
-                $this->setActionFile($router['forwardAction']);
+                if (preg_match('/^\/(.+)$/', $router['forwardAction'], $matches)) {
+                    $this->action_file = $matches[1];
+                } else {
+                    $this->action_file = $router['forwardAction'];
+                }
             }
             if ($router['enableTemplate'] && $router['forwardTemplate']) {
                 $this->setTemplateFile($router['forwardTemplate']);
