@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.27 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.28 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.27 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.28 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -57,14 +57,14 @@ class SyL_View
      * @access protected
      * @var bool
      */
-    var $content_length = true;
+    var $content_length = SYL_RESPONSE_LENGTH;
     /**
      * gzipȽ
      * 
      * @access protected
      * @var bool
      */
-    var $gzip_compress = true;
+    var $gzip_compress = SYL_RESPONSE_GZIP;
     /**
      * ɽƤΥǡ
      * 
@@ -79,6 +79,13 @@ class SyL_View
      * @var object
      */
     var $context = null;
+    /**
+     * 롼饹
+     * 
+     * @access protected
+     * @var object
+     */
+    var $router = null;
     /**
      * ե졼ǡݻ饹
      * 
@@ -97,6 +104,7 @@ class SyL_View
     {
         $this->context =& $context;
         $this->data    =& $data;
+        $this->router  =& $context->getRouter();
     }
 
     /**
@@ -109,8 +117,10 @@ class SyL_View
      */
     function &getObject(&$context, &$data)
     {
+        $router =& $context->getRouter();
+
         $view      = null;
-        $type      = $context->getViewType();
+        $type      = $router->getViewType();
         $classname = '';
         $classfile = '';
 
@@ -136,25 +146,25 @@ class SyL_View
     }
 
     /**
-     * ƥץ졼ȥǥ쥯ȥ
-     * 
+     * ƥץ졼ȥǥ쥯ȥ롼Ȥ
+     *
      * @access public
-     * @return string ƥץ졼ȥǥ쥯ȥ
+     * @return string ƥץ졼ȥǥ쥯ȥ롼
      */
     function getTemplateDir()
     {
-        return $this->context->getTemplateDir();
+        return $this->router->getTemplateDir();
     }
 
     /**
      * ƥץ졼ȥե
-     * 
+     *
      * @access public
      * @return string ƥץ졼ȥե
      */
     function getTemplateFile()
     {
-        return $this->context->getTemplateFile();
+        return $this->router->getTemplateFile();
     }
 
     /**
@@ -187,7 +197,7 @@ class SyL_View
      */
     function isContentLength()
     {
-        return (SYL_RESPONSE_LENGTH) ? $this->content_length : false;
+        return (bool)$this->content_length;
     }
 
     /**
@@ -198,7 +208,7 @@ class SyL_View
      */
     function isGzipCompress()
     {
-        return (SYL_RESPONSE_GZIP) ? $this->gzip_compress : false;
+        return (bool)$this->gzip_compress;
     }
 
     /**
@@ -241,7 +251,7 @@ class SyL_View
     /**
      * HTML󥰼¹
      * 
-     * @access public
+     * @access abstract
      */
     function render()
     {
