@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJs.php,v 1.11 2008/03/29 06:11:46 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJs.php,v 1.12 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJs.php,v 1.11 2008/03/29 06:11:46 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJs.php,v 1.12 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewJs extends SyL_View
@@ -114,7 +114,7 @@ class SyL_ViewJs extends SyL_View
         ob_start();
         foreach ($imports as $mode) {
             $included = false;
-            $file = SyL_Loader::convertPath($mode, 'js');
+            $file = SyL_Loader::convertPath($mode, 'SyL', 'js');
             foreach ($paths1 as $path) {
                 if (is_file($path . $file)) {
                     include_once $path . $file;
@@ -124,7 +124,7 @@ class SyL_ViewJs extends SyL_View
             }
             if ($included) continue;
 
-            $file = SyL_Loader::convertPathSyL("JsClient.{$mode}", 'js');
+            $file = SyL_Loader::convertPath("JsClient.{$mode}", 'SyL', 'js');
             foreach ($paths2 as $path) {
                 if (is_file($path . $file)) {
                     include_once $path . $file;
