@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayout.php,v 1.11 2008/11/09 10:05:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayout.php,v 1.12 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,18 +39,11 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayout.php,v 1.11 2008/11/09 10:05:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayout.php,v 1.12 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayout extends SyL_View
 {
-    /**
-     * 쥤ե̾
-     * 
-     * @access private
-     * @param string
-     */
-    var $layout_file_name = 'layouts.xml';
     /**
      * 쥤ե
      * 
@@ -85,16 +78,38 @@ class SyL_ViewLayout extends SyL_View
     }
 
     /**
-     * ƥץ졼ȥե
+     * 쥤ȥե
      * 
      * @access public
      * @return string ƥץ졼ȥե
      */
-    function getTemplateFile()
+    function getLayoutFile()
     {
         return $this->config['file'];
     }
 
+    /**
+     * ʬƥץ졼ȥե
+     * 
+     * @access public
+     * @return array ʬƥץ졼ȥե
+     */
+    function getTemplateFiles()
+    {
+        return $this->config['templates'];
+    }
+
+    /**
+     * ƥĥե
+     * 
+     * @access public
+     * @return string ƥĥե
+     */
+    function getContentFile()
+    {
+        return $this->router->getTemplateFile();
+    }
+
     /**
      * ѥ᡼
      * 
@@ -107,10 +122,10 @@ class SyL_ViewLayout extends SyL_View
 
         // 쥤
         if (isset($this->config['templates'])) {
-            $values += $this->config['templates'];
+            $values += $this->getTemplateFiles();
         }
         if (isset($this->config['content']) && $this->config['content']) {
-            $values[$this->config['content']] = $this->router->getTemplateFile();
+            $values[$this->config['content']] = $this->getContentFile();
         } else {
             SyL_Loggers::notice("Content context not found");
         }
