@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.9 2008/11/09 10:05:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.10 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,11 +44,48 @@ require_once 'SyL_ViewLayout.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.9 2008/11/09 10:05:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.10 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayoutDefault extends SyL_ViewLayout
 {
+    /**
+     * 쥤ȥեХѥѴƤ
+     * 
+     * @access public
+     * @return string ƥץ졼ȥե
+     */
+    function getLayoutFile()
+    {
+        return $this->router->getTemplateDir() . $this->config['file'];
+    }
+
+    /**
+     * ʬƥץ졼ȥեХѥѴƤ
+     * 
+     * @access public
+     * @return array ʬƥץ졼ȥե
+     */
+    function getTemplateFiles()
+    {
+        $template_files = array();
+        foreach ($this->config['templates'] as $name => $value) {
+            $template_files[$name] = $this->router->getTemplateDir() . $value;
+        }
+        return $template_files;
+    }
+
+    /**
+     * ƥĥեХѥѴƤ
+     * 
+     * @access public
+     * @return string ƥĥե
+     */
+    function getContentFile()
+    {
+        return $this->router->getTemplateDir() . $this->router->getTemplateFile();
+    }
+
     /**
      * HTML󥰼¹
      * 
@@ -66,12 +103,9 @@ class SyL_ViewLayoutDefault extends SyL_ViewLayout
             }
         }
 
-        // ƥץ졼ȼ
-        $template_file = $this->getTemplateDir() . $this->getTemplateFile();
-
         // ɽƤ򥻥å
         ob_start();
-        include_once $template_file;
+        include_once $this->getLayoutFile();
         $this->setRender(ob_get_clean());
     }
 }
