@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.13 2008/11/09 10:05:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.14 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_SMARTY_DIR . 'Smarty.class.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.13 2008/11/09 10:05:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.14 2008/12/01 17:45:52 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayoutSmarty extends SyL_ViewLayout
@@ -103,7 +103,7 @@ class SyL_ViewLayoutSmarty extends SyL_ViewLayout
         // ƥץ졼ȥǥ쥯ȥꥻå
         $this->smarty->template_dir = $this->getTemplateDir();
         // ɽƤ򥻥å
-        $this->setRender($this->smarty->fetch($this->getTemplateFile()));
+        $this->setRender($this->smarty->fetch($this->getLayoutFile()));
     }
 }
 
