@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.8 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.9 2008/12/01 17:45:53 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.8 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.9 2008/12/01 17:45:53 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDaoTable
@@ -146,8 +146,33 @@ class SyL_DBDaoTable
         // ̾ʸѴ
         $this->primary = array_map('strtoupper', $this->primary);
         $this->columns = array_change_key_case($this->columns, CASE_UPPER);
+
+        // PHP4.xΥС
+        if (version_compare(PHP_VERSION, '5.0.0', '<')) {
+            //overload(get_class($this));
+        }
     }
 
+    /**
+     * ͤɲäΥСɥ᥽å
+     *
+     * @access public
+     * @param string ᥽å̾
+     * @param array 
+     * @param mixed 
+     */
+/*
+    function __call($method, $args, &$return)
+    {
+        if (preg_match('/^set(.+)/', $method, $matches)) {
+            $column_name = strtoupper($matches[1]);
+            $this->set($column_name, $args[0]);
+            return true;
+        } else {
+            return false;
+        }
+    }
+*/
     /**
      * ͤɲ
      *
@@ -156,7 +181,7 @@ class SyL_DBDaoTable
      * @param mixed 
      * @param array SQLؿ
      */
-    function addColumn($name, $value=null, $function=null)
+    function set($name, $value=null, $function=null)
     {
         // ʸ
         $name = strtoupper($name);
