@@ -35,7 +35,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.10 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.11 2008/12/01 17:45:53 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -56,7 +56,7 @@ require_once 'SyL_DBSqlTableRelations.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.10 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.11 2008/12/01 17:45:53 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDao
@@ -445,7 +445,7 @@ class SyL_DBDao
             }
             $table->setConditions($condition);
         }
-        $table->addColumn($column, 'MAXID', array('MAX'));
+        $table->set($column, 'MAXID', array('MAX'));
         $result = $this->select($table);
         return (count($result) > 0) ? $result[0]['MAXID'] : null;
     }
