@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSchema.php,v 1.5 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSchema.php,v 1.6 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSchema.php,v 1.5 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSchema.php,v 1.6 2008/08/31 13:58:49 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBSchema
@@ -72,7 +72,8 @@ class SyL_DBSchema
      */
     function &factory(&$conn)
     {
-        switch (strtolower($conn->dbtype)) {
+        $type = $conn->getType();
+        switch (strtolower($type)) {
         case 'mysql':
         case 'mysqli':
         case 'pdomysql':
@@ -85,7 +86,7 @@ class SyL_DBSchema
         default:
             trigger_error("[SyL error] Not supported DB type schema ({$type})", E_USER_ERROR);
         }
-        
+
         $classname = "SyL_DBSchema{$type}";
         include_once dirname(__FILE__) . "/Schema/{$classname}.php";
         $schema =& new $classname($conn);
