@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Project.php,v 1.4 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: Project.php,v 1.5 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Project.php,v 1.4 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: Project.php,v 1.5 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Project extends AppAction
@@ -61,6 +61,7 @@ class Project extends AppAction
     {
         $project_dir     = $data->geta('d', 0);
         $app_name        = $data->geta('w', 0);
+        $is_controller   = $data->is('c');
         $controller_file = $data->geta('c', 0);
         $smarty_dir      = $data->geta('s', 0);
 
@@ -120,23 +121,26 @@ class Project extends AppAction
         // -------------------------------------------------
         // ȥեå
         // -------------------------------------------------
-        if ($controller_file) {
-            if ($app_name == '') {
-                trigger_error("[SyL error] Application name not found for create controller", E_USER_ERROR);
-                exit;
-            } else if (file_exists($controller_file)) {
+        if ($is_controller) {
+            if (!$controller_file) {
+                // ǥեȤΥȥե
+                $controller_file = "{$project_dir}public/{$app_name}.php";
+            }
+            if (file_exists($controller_file)) {
                 if ($cmd->getInput('Already controller file exists', "overwrite controller file ({$controller_file}) [Y/n]:") != 'Y') {
                     $cmd->stdout('*** ' . $data->get(0) . ' stopped');
                     exit;
                 }
                 if (!is_writable($controller_file)) {
-                    trigger_error("[SyL error] Create controller file permission denied ({$controller_file})", E_USER_ERROR);
+                    trigger_error("[SyL error] Controller file permission denied ({$controller_file})", E_USER_ERROR);
                     exit;
                 }
             } else {
-                if (!is_writable(dirname($controller_file))) {
-                    trigger_error("[SyL error] Create controller file permission denied ({$controller_file})", E_USER_ERROR);
-                    exit;
+                if (is_dir(dirname($controller_file))) {
+                    if (!is_writable(dirname($controller_file))) {
+                        trigger_error("[SyL error] Controller file permission denied ({$controller_file})", E_USER_ERROR);
+                        exit;
+                    }
                 }
             }
         }
@@ -144,7 +148,7 @@ class Project extends AppAction
         // -------------------------------------------------
         // SMARTY_DIRå
         // -------------------------------------------------
-        if ($data->is('s')) {
+        if ($smarty_dir) {
             if (!is_dir($smarty_dir)) {
                 trigger_error("[SyL error] Smarty dir not found", E_USER_ERROR);
                 exit;
@@ -153,7 +157,7 @@ class Project extends AppAction
                 $smarty_dir .= '/';
             }
             if (!is_file($smarty_dir . 'Smarty.class.php')) {
-                trigger_error("[SyL error] `Smarty.class.php' not found", E_USER_ERROR);
+                trigger_error("[SyL error] `Smarty.class.php' not found ({$smarty_dir}Smarty.class.php)", E_USER_ERROR);
                 exit;
             }
         }
