@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateAction.php,v 1.4 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: CreateAction.php,v 1.5 2008/07/27 14:53:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateAction.php,v 1.4 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: CreateAction.php,v 1.5 2008/07/27 14:53:09 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class CreateAction
@@ -83,8 +83,8 @@ class CreateAction
             // 饹̾Ѵ
             $class_name = implode('_', array_map('ucfirst', preg_split('/(\\\\|\/)/', $action_file[$i])));
             $trans = array(
-              '{SYL_CLASS}' => $class_name,
-              '{APP_NAME}'  => $app_name
+              '{{SYL_CLASS}}' => $class_name,
+              '{{APP_NAME}}'  => $app_name
             );
             $contents_tmp = strtr($contents, $trans);
 
