@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.9 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: CreateApplication.php,v 1.10 2008/12/01 17:45:53 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.9 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: CreateApplication.php,v 1.10 2008/12/01 17:45:53 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class CreateApplication
@@ -84,8 +84,8 @@ class CreateApplication
           'filters.xml'     => 'config/filters.xml',
           'layouts.xml'     => 'config/layouts.xml',
           'routers.xml'     => 'config/routers.xml',
-          'AppAction.php'   => 'lib/App/Action.php',
-          'AppUser.php'     => 'lib/App/User.php'
+          'AppAction.php'   => 'lib/App/AppAction.php',
+          'AppUser.php'     => 'lib/App/AppUser.php'
         );
 
         foreach ($dirs as $dir => $mode) {
