@@ -1,14 +1,14 @@
 <?php
 /**
- * {SYL_CLASS} 饹
+ * {{SYL_CLASS}} 饹
  *
  * @access    public
- * @package   {APP_NAME}
+ * @package   {{APP_NAME}}
  * @author    {author}
  * @copyright {copyright}
- * @version   $Id: action.php,v 1.4 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   $Id: action.php,v 1.5 2008/07/27 14:53:10 seasonstream Exp $
  */
-class {SYL_CLASS} extends AppAction
+class {{SYL_CLASS}} extends AppAction
 {
     /**
      * ǥեȥ
