@@ -12,13 +12,13 @@ require_once '{{SYL_DIR}}/SyL.php';
  *  project_dir - ץȥǥ쥯ȥ
  *  app_name    - ץꥱ̾
  *  action_key  - ѥ᡼Υ̾
- *  cache       - åˡʢ̤ϤǥåѤʤ
+ *  cache       - å̵ͭ
  */
 $config = array(
   'project_dir'  => '{{PROJECT_DIR}}',
   'app_name'     => '{{APP_NAME}}',
   'action_key'   => 'action',
-  'cache'        => 'file'
+  'cache'        => true
 );
 
 /**
